/*
 * Copyright 2007-2018 The jdeb developers.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.vafer.jdeb.ant;

import org.junit.Test;
import org.junit.Assert;

import org.apache.tools.ant.types.selectors.SelectorUtils;

public final class AntSelectorTestCase extends Assert {

    @Test
    public void testExclusion() throws Exception {
        assertTrue("should match",
            SelectorUtils.matchPath("**/bin/**", "/some/bin/stuff"));
        assertFalse("should not match",
            SelectorUtils.matchPath("**/bin/**", "/some/stuff"));
    }
}
